@@ -95,10 +95,7 @@ public class NamedArgumentDefinition extends ArgumentDefinition {
      */
     public String getLongName() { return !getFullName().isEmpty() ? getFullName() : getUnderlyingField().getName(); }
 
-    /**
-     * the doc string for this argument, if any.
-     * @return doc string. can be empty.
-     */
+    @Override
     public String getDocString() { return argumentAnnotation.doc(); }
 
     /**
@@ -131,12 +128,6 @@ public class NamedArgumentDefinition extends ArgumentDefinition {
      */
     public boolean isAdvanced() { return getUnderlyingField().getAnnotation(Advanced.class) != null; }
 
-    /**
-     * return true if this argument has the {@code @Deprecated} annotation.
-     * @return true if this argument is advanced, otherwise false.
-     */
-    public boolean isDeprecated() { return getUnderlyingField().isAnnotationPresent(Deprecated.class); }
-
     /**
      * return true if this argument is a flag (boolean valued) argument
      * @return true if this argument is boolean valued
@@ -439,7 +430,7 @@ public class NamedArgumentDefinition extends ArgumentDefinition {
 
         final StringBuilder sb = new StringBuilder();
         sb.append("--").append(getLongName());
-        if (!getShortName().isEmpty()) {
+        if (!getShortName().isEmpty() && !getShortName().equals(getLongName())) {
             sb.append(",-").append(getShortName());
         }
 
@@ -451,19 +442,14 @@ public class NamedArgumentDefinition extends ArgumentDefinition {
             sb.append("\n");
             numSpaces = argumentColumnWidth;
         }
-        printSpaces(sb, numSpaces);
+        Utils.printSpaces(sb, numSpaces);
 
-        final String description = getArgumentDescription(allActualArguments, pluginDescriptors);
-        final String wrappedDescription = Utils.wrapParagraph(description, descriptionColumnWidth);
-        final String[] descriptionLines = wrappedDescription.split("\n");
-        for (int i = 0; i < descriptionLines.length; ++i) {
-            if (i > 0) {
-                printSpaces(sb, argumentColumnWidth);
-            }
-            sb.append(descriptionLines[i]);
-            sb.append("\n");
-        }
+        sb.append(getFormattedDescription(
+                getArgumentDescription(allActualArguments, pluginDescriptors),
+                argumentColumnWidth,
+                descriptionColumnWidth));
         sb.append("\n");
+
         return sb.toString();
     }
 
@@ -617,7 +603,7 @@ public class NamedArgumentDefinition extends ArgumentDefinition {
                     } else {
                         sb.append(OPTION_DOC_PREFIX);
                         sb.append(String.join(", ", allowedValues.stream().sorted(String::compareToIgnoreCase).collect(Collectors.toList())));
-                        sb.append(OPTION_DOC_PREFIX);
+                        sb.append(OPTION_DOC_SUFFIX);
                     }
                     return true;
                 }
@@ -692,12 +678,6 @@ public class NamedArgumentDefinition extends ArgumentDefinition {
                 || getMaxValue() != Double.POSITIVE_INFINITY && value > getMaxValue();
     }
 
-    private static void printSpaces(final StringBuilder sb, final int numSpaces) {
-        for (int i = 0; i < numSpaces; ++i) {
-            sb.append(" ");
-        }
-    }
-
     @Override
     public boolean equals(Object o) {
         if (this == o) return true;
