@@ -14,7 +14,7 @@ import java.util.*;
  */
 public class CollectionArgumentUnitTests {
 
-    class UninitializedCollections {
+    private class UninitializedCollections {
         @Argument
         public List<String> LIST;
         @Argument
@@ -73,7 +73,7 @@ public class CollectionArgumentUnitTests {
         Assert.assertEquals(o.COLLECTION, expectedCollection);
     }
 
-    class InitializedCollections {
+    private class InitializedCollections {
         @Argument
         public List<String> LIST = makeList("foo", "bar");
     }
@@ -146,12 +146,12 @@ public class CollectionArgumentUnitTests {
     //////////////////////////////////////////////////////////////////
     // tests for .list/.args file expansion
 
-    abstract class CollectionForListFileArguments {
+    private abstract class CollectionForListFileArguments {
         abstract List<String> getList1();
         abstract List<String> getList2();
     }
 
-    class EnabledListFileArguments extends CollectionForListFileArguments {
+    private class EnabledListFileArguments extends CollectionForListFileArguments {
 
         @Argument
         public List<String> LIST = makeList("foo", "bar");
@@ -164,7 +164,7 @@ public class CollectionArgumentUnitTests {
         public List<String> getList2() { return LIST2; };
     }
 
-    class SuppressedListFileArguments extends CollectionForListFileArguments {
+    private class SuppressedListFileArguments extends CollectionForListFileArguments {
 
         @Argument(suppressFileExpansion = true)
         public List<String> LIST = makeList("foo", "bar");
@@ -187,7 +187,7 @@ public class CollectionArgumentUnitTests {
                         new EnabledListFileArguments(),
                         Collections.EMPTY_SET,                                                  // parser options
                         createTemporaryExpansionFile("enabledExpansion",
-                                CommandLineArgumentParser.COLLECTION_LIST_FILE_EXTENSIONS_ARGS),// expansion file
+                                CommandLineArgumentParser.EXPANSION_FILE_EXTENSIONS_ARGS),// expansion file
                         expansionFileContents,                                                  // args for expansion file
                         new String[] {"shmiggle0", "shmiggle1", "shmiggle2"},                   // expected result
                         false                                                                   // expect temp file name
@@ -197,7 +197,7 @@ public class CollectionArgumentUnitTests {
                         new EnabledListFileArguments(),
                         Collections.singleton(CommandLineParserOptions.APPEND_TO_COLLECTIONS),  // parser options
                         createTemporaryExpansionFile("enabledExpansion",
-                                CommandLineArgumentParser.COLLECTION_LIST_FILE_EXTENSIONS_ARGS),// expansion file
+                                CommandLineArgumentParser.EXPANSION_FILE_EXTENSIONS_ARGS),// expansion file
                         expansionFileContents,                                                  // args for expansion file
                         new String[] {"foo", "bar", "shmiggle0", "shmiggle1", "shmiggle2"},     // expected result
                         false                                                                   // expect temp file name
@@ -207,7 +207,7 @@ public class CollectionArgumentUnitTests {
                         new EnabledListFileArguments(),
                         Collections.EMPTY_SET,                                                  // parser options
                         createTemporaryExpansionFile("enabledExpansion",
-                                CommandLineArgumentParser.COLLECTION_LIST_FILE_EXTENSIONS_LIST),// expansion file
+                                CommandLineArgumentParser.EXPANSION_FILE_EXTENSION_LIST),// expansion file
                         expansionFileContents,                                                  // args for expansion file
                         new String[] {"shmiggle0", "shmiggle1", "shmiggle2"},                   // expected result
                         false                                                                   // expect temp file name
@@ -217,7 +217,7 @@ public class CollectionArgumentUnitTests {
                         new EnabledListFileArguments(),
                         Collections.singleton(CommandLineParserOptions.APPEND_TO_COLLECTIONS),  // parser options
                         createTemporaryExpansionFile("enabledExpansion",
-                                CommandLineArgumentParser.COLLECTION_LIST_FILE_EXTENSIONS_LIST),// expansion file
+                                CommandLineArgumentParser.EXPANSION_FILE_EXTENSION_LIST),// expansion file
                         expansionFileContents,                                                  // args for expansion file
                         new String[] {"foo", "bar", "shmiggle0", "shmiggle1", "shmiggle2"},     // expected result
                         false                                                                   // expect temp file name
@@ -229,7 +229,7 @@ public class CollectionArgumentUnitTests {
                         new SuppressedListFileArguments(),
                         Collections.EMPTY_SET,                                                  // parser options
                         createTemporaryExpansionFile("enabledExpansion",
-                                CommandLineArgumentParser.COLLECTION_LIST_FILE_EXTENSIONS_ARGS),// expansion file
+                                CommandLineArgumentParser.EXPANSION_FILE_EXTENSIONS_ARGS),// expansion file
                         expansionFileContents,                                                  // args for expansion file
                         new String[] {},                                                        // expected result
                         true,
@@ -239,7 +239,7 @@ public class CollectionArgumentUnitTests {
                         new SuppressedListFileArguments(),
                         Collections.singleton(CommandLineParserOptions.APPEND_TO_COLLECTIONS),  // parser options
                         createTemporaryExpansionFile("enabledExpansion",
-                                CommandLineArgumentParser.COLLECTION_LIST_FILE_EXTENSIONS_ARGS),// expansion file
+                                CommandLineArgumentParser.EXPANSION_FILE_EXTENSIONS_ARGS),// expansion file
                         expansionFileContents,                                                  // args for expansion file
                         new String[] {"foo", "bar"},                                            // expected result
                         true,
@@ -249,7 +249,7 @@ public class CollectionArgumentUnitTests {
                         new SuppressedListFileArguments(),
                         Collections.EMPTY_SET,                                                  // parser options
                         createTemporaryExpansionFile("enabledExpansion",
-                                CommandLineArgumentParser.COLLECTION_LIST_FILE_EXTENSIONS_LIST),// expansion file
+                                CommandLineArgumentParser.EXPANSION_FILE_EXTENSION_LIST),// expansion file
                         expansionFileContents,                                                  // args for expansion file
                         new String[] {},                                                        // expected result
                         true,
@@ -259,7 +259,7 @@ public class CollectionArgumentUnitTests {
                         new SuppressedListFileArguments(),
                         Collections.singleton(CommandLineParserOptions.APPEND_TO_COLLECTIONS),  // parser options
                         createTemporaryExpansionFile("enabledExpansion",
-                                CommandLineArgumentParser.COLLECTION_LIST_FILE_EXTENSIONS_LIST),// expansion file
+                                CommandLineArgumentParser.EXPANSION_FILE_EXTENSION_LIST),// expansion file
                         expansionFileContents,                                                  // args for expansion file
                         new String[] {"foo", "bar"},                                            // expected result
                         true,
@@ -303,6 +303,29 @@ public class CollectionArgumentUnitTests {
         Assert.assertEquals(argumentContainer.getList1(), expectedResult);
     }
 
+    private class PositionalCollection {
+        @PositionalArguments
+        public List<String> positionalCollection = new ArrayList<>();
+    }
+
+    @Test
+    public void testPositionalCollectionFromExpansionFile() throws IOException
+    {
+        final PositionalCollection positionalCollection = new PositionalCollection();
+        final CommandLineParser clp = new CommandLineArgumentParser(positionalCollection);
+
+        final File expansionFile = createTemporaryExpansionFile("enabledExpansion",
+                CommandLineArgumentParser.EXPANSION_FILE_EXTENSION_LIST);
+
+        final String[] expansionFileContentsArray = new String[] {"value1", "value2", "value3"};
+        populateExpansionFile(expansionFile, expansionFileContentsArray);
+
+        // use a single file argument
+        Assert.assertTrue(clp.parseArguments(System.err, new String[] { expansionFile.getAbsolutePath() }));
+
+        Assert.assertEquals(positionalCollection.positionalCollection, Arrays.asList(expansionFileContentsArray));
+    }
+
     @DataProvider(name="mixedListFileArguments")
     public Object[][] mixedListFileArguments() {
         final String[] inputArgList1 = { "shmiggle0", "shmiggle1", "shmiggle2" };
@@ -354,9 +377,9 @@ public class CollectionArgumentUnitTests {
     ) throws IOException {
 
         // use two file arguments
-        final File listFile = createTemporaryExpansionFile("testFile1", CommandLineArgumentParser.COLLECTION_LIST_FILE_EXTENSIONS_ARGS);
+        final File listFile = createTemporaryExpansionFile("testFile1", CommandLineArgumentParser.EXPANSION_FILE_EXTENSIONS_ARGS);
         populateExpansionFile(listFile, argList1);
-        final File listFile2 = createTemporaryExpansionFile("testFile2", CommandLineArgumentParser.COLLECTION_LIST_FILE_EXTENSIONS_LIST);
+        final File listFile2 = createTemporaryExpansionFile("testFile2", CommandLineArgumentParser.EXPANSION_FILE_EXTENSION_LIST);
         populateExpansionFile(listFile2, argList2);
         final CommandLineParser clp = new CommandLineArgumentParser(
                 argumentContainer,
@@ -389,11 +412,11 @@ public class CollectionArgumentUnitTests {
         final CommandLineArgumentParser clp = new CommandLineArgumentParser(fo);
         Assert.assertTrue(clp.parseArguments(System.err, args));
          final String expectedCommandLine =
-                 String.format("EnabledListFileArguments  --LIST commandLineValue --LIST %s --LIST2 anotherCommandLineValue  ", expansionFile.getAbsolutePath());
+                 String.format("EnabledListFileArguments --LIST commandLineValue --LIST %s --LIST2 anotherCommandLineValue", expansionFile.getAbsolutePath());
         Assert.assertEquals(clp.getCommandLine(), expectedCommandLine);
     }
 
-    class NonCollectionFileExpansionSuppression {
+    private class NonCollectionFileExpansionSuppression {
         @Argument(suppressFileExpansion = true)
         public int bogusFileExpansionArg;
     }
@@ -404,7 +427,7 @@ public class CollectionArgumentUnitTests {
         final CommandLineArgumentParser clp = new CommandLineArgumentParser(fo);
     }
 
-    class UninitializedCollectionThatCannotBeAutoInitializedArguments {
+    private class UninitializedCollectionThatCannotBeAutoInitializedArguments {
         @Argument
         public Set<String> SET;
     }
